@@ -1,10 +1,10 @@
 package Data::Microformat::hCard;
-use base qw(Data::Microformat::hCard::base);
+use base qw(Data::Microformat);
 
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use Data::Microformat::adr;
 use Data::Microformat::geo;
@@ -120,6 +120,7 @@ sub from_tree
 				my $nested_goes_here;
 				my $hcard_class = $bit->attr('class');
 				next unless $hcard_class;
+				
 				#Check for nested vcard.
 				if ($hcard_class =~ m/vcard/)
 				{
@@ -354,7 +355,7 @@ Data::Microformat::hCard - A module to parse and create hCards
 
 =head1 VERSION
 
-This documentation refers to Data::Microformat::hCard version 0.01.
+This documentation refers to Data::Microformat::hCard version 0.03.
 
 =head1 SYNOPSIS
 
@@ -453,7 +454,7 @@ called in scalar context.
 =head2 Data::Microformat::organization->from_tree($tree [, $source_url])
 
 This method overrides but provides the same functionality as the
-method of the same name in L<Data::Microformat::hCard::base>, with the optional
+method of the same name in L<Data::Microformat>, with the optional
 addition of $source_url. If present, this latter term will trigger a search to
 find the "representative hCard" for the given page, using the specifications
 for representative hCard parsing; a card's status of representative or not can
